@@ -40,6 +40,7 @@ __all__ = (
     "DescribeProtectedResourceOutputTypeDef",
     "CalculatedLifecycleTypeDef",
     "DescribeRecoveryPointOutputTypeDef",
+    "DescribeRegionSettingsOutputTypeDef",
     "DescribeRestoreJobOutputTypeDef",
     "ExportBackupPlanTemplateOutputTypeDef",
     "BackupRuleTypeDef",
@@ -270,6 +271,12 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
     total=False,
 )
 
+DescribeRegionSettingsOutputTypeDef = TypedDict(
+    "DescribeRegionSettingsOutputTypeDef",
+    {"ResourceTypeOptInPreference": Dict[str, bool]},
+    total=False,
+)
+
 DescribeRestoreJobOutputTypeDef = TypedDict(
     "DescribeRestoreJobOutputTypeDef",
     {
